==> polymer-core-0.9.19+1.21.1-sources.jar: eu/pb4/polymer/core/impl/PolymerMod.java <==
package eu.pb4.polymer.core.impl;

import eu.pb4.polymer.common.api.PolymerCommonUtils;
import eu.pb4.polymer.common.impl.CommonImplUtils;
import eu.pb4.polymer.common.impl.CompatStatus;
import eu.pb4.polymer.core.api.block.PolymerBlockUtils;
import eu.pb4.polymer.core.api.item.PolymerItem;
import eu.pb4.polymer.core.api.utils.PolymerUtils;
import eu.pb4.polymer.core.impl.client.compat.FabricFluids;
import eu.pb4.polymer.core.impl.client.networking.PolymerClientProtocolHandler;
import eu.pb4.polymer.core.impl.compat.polymc.PolyMcUtils;
import eu.pb4.polymer.core.impl.networking.PolymerServerProtocolHandler;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.api.ModInitializer;
import net.minecraft.class_3244;
import org.jetbrains.annotations.ApiStatus;


@ApiStatus.Internal
public class PolymerMod implements ModInitializer, ClientModInitializer {
	@Override
	public void onInitialize() {
		CommonImplUtils.registerCommands(Commands::register);
		CommonImplUtils.registerDevCommands(Commands::registerDev);

		PolymerServerProtocolHandler.register();
		PolymerCommonUtils.ON_RESOURCE_PACK_STATUS_CHANGE.register(((handler, uuid, oldStatus, newStatus) -> {
			if (oldStatus != newStatus && handler instanceof class_3244 handler1) {
				PolymerUtils.reloadWorld(handler1.field_14140);
			}
		}));

		PolyMcUtils.register();

		if (PolymerImpl.FORCE_STRICT_UPDATES) {
			PolymerBlockUtils.requireStrictBlockUpdates();
		}
	}
	@Override
	public void onInitializeClient() {
		PolymerClientProtocolHandler.register();

		if (CompatStatus.FABRIC_FLUID_RENDERING) {
			FabricFluids.register();
		}
	}
}

==> polymer-core-0.15.1+1.21.11-sources.jar: eu/pb4/polymer/core/impl/PolymerMod.java <==
package eu.pb4.polymer.core.impl;

import eu.pb4.polymer.common.api.PolymerCommonUtils;
import eu.pb4.polymer.common.impl.CommonImplUtils;
import eu.pb4.polymer.common.impl.CompatStatus;
import eu.pb4.polymer.core.api.block.PolymerBlockUtils;
import eu.pb4.polymer.core.api.item.PolymerItem;
import eu.pb4.polymer.core.api.utils.PolymerUtils;
import eu.pb4.polymer.core.impl.client.InternalClientRegistry;
import eu.pb4.polymer.core.impl.client.compat.FabricFluids;
import eu.pb4.polymer.core.impl.client.networking.PolymerClientProtocolHandler;
import eu.pb4.polymer.core.impl.compat.polymc.PolyMcUtils;
import eu.pb4.polymer.core.impl.networking.PolymerServerProtocolHandler;
import eu.pb4.polymer.core.impl.networking.entry.PolymerBlockEntry;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.api.ModInitializer;
import net.minecraft.class_3244;
import net.minecraft.class_7923;
import org.jetbrains.annotations.ApiStatus;


@ApiStatus.Internal
public class PolymerMod implements ModInitializer, ClientModInitializer {
	@Override
	public void onInitialize() {
		CommonImplUtils.registerCommands(Commands::register);
		CommonImplUtils.registerDevCommands(Commands::registerDev);

		PolymerServerProtocolHandler.register();
		PolymerCommonUtils.ON_RESOURCE_PACK_STATUS_CHANGE.register(((handler, uuid, oldStatus, newStatus) -> {
			if (oldStatus != newStatus && handler instanceof class_3244 handler1) {
				PolymerUtils.reloadWorld(handler1.field_14140);
			}
		}));
		ImplPolymerRegistryEvent.iterateAndRegister(class_7923.field_41175, PolymerBlockEntry::cacheCalcDeltaOverride);


		PolyMcUtils.register();
	}
	@Override
	public void onInitializeClient() {
		PolymerClientProtocolHandler.register();
		InternalClientRegistry.register();

		if (CompatStatus.FABRIC_FLUID_RENDERING) {
			FabricFluids.register();
		}
	}
}
